smetrics

package module
v0.2.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 7, 2025 License: MIT Imports: 14 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewLoggerHTTPProvider added in v0.1.2

func NewLoggerHTTPProvider(ctx context.Context, res *resource.Resource) (*log.LoggerProvider, error)

NewLoggerHTTPProvider creates a new logger provider with the OTLP HTTP exporter.

func NewMeterHTTPProvider added in v0.1.2

func NewMeterHTTPProvider(ctx context.Context, res *resource.Resource) (*metric.MeterProvider, error)

NewMeterHTTPProvider creates a new meter provider with the OTLP HTTP exporter.

func NewResource added in v0.1.2

func NewResource(serviceName string, serviceVersion string) *resource.Resource

NewResource creates a new OTEL resource with the service name and version.

func NewTracerHTTPProvider added in v0.1.2

func NewTracerHTTPProvider(ctx context.Context, res *resource.Resource) (*trace.TracerProvider, error)

NewTracerHTTPProvider creates a new tracer provider with the OTLP HTTP exporter.

Types

type Metric

type Metric struct {
	Name        string
	Unit        string
	Description string
}

Metric represents a metric that can be collected by the server.

Jump to